import{s as a,c as s,a as t,C as e}from"./chunk-V7JOEXUC-DAzqWBNq.js";import{_ as i}from"./mermaid.core-FAsvc-qs.js";import"./chunk-5VM5RSS4-DU3Ekj64.js";import"./chunk-XXDRQBXY-CZyPlTXo.js";import"./chunk-VR4S4FIN-DtABaMf8.js";import"./chunk-32BRIVSS-BjdMbPva.js";import"./index-D5cbSL06.js";import"./react-vendor-BMp1-Y7_.js";import"./highlight-Cfs1Rmle.js";import"./katex-C-yOSGt_.js";import"./markdown-DlgIKD8F.js";import"./router-B9Gh0kMO.js";var w={parser:t,get db(){return new e},renderer:s,styles:a,init:i(r=>{r.class||(r.class={}),r.class.arrowMarkerAbsolute=r.arrowMarkerAbsolute},"init")};export{w as diagram};
