import{c as r,s as e}from"./flowDiagram-23GEKE2U-By1NHsCV.js";import{_ as o}from"./mermaid.core-FAsvc-qs.js";import"./chunk-5VM5RSS4-DU3Ekj64.js";import"./chunk-XXDRQBXY-CZyPlTXo.js";import"./chunk-VR4S4FIN-DtABaMf8.js";import"./chunk-32BRIVSS-BjdMbPva.js";import"./channel-tMwm3ju2.js";import"./index-D5cbSL06.js";import"./react-vendor-BMp1-Y7_.js";import"./highlight-Cfs1Rmle.js";import"./katex-C-yOSGt_.js";import"./markdown-DlgIKD8F.js";import"./router-B9Gh0kMO.js";var a=o(t=>`${e(t)}
  .swimlane.cluster rect {
    stroke: ${t.clusterBorder} !important;
  }
  [data-look="neo"].cluster rect {
    filter: none;
  }
`,"getStyles"),m=a,w=r({defaultLayout:"swimlane",styles:m});export{w as diagram};
