import{j as t}from"./react-vendor-BMp1-Y7_.js";import{u as n,T as c}from"./index-D5cbSL06.js";import{A as p,P as u}from"./plans-panel-D7FdRwSK.js";import"./highlight-Cfs1Rmle.js";import"./katex-C-yOSGt_.js";import"./markdown-DlgIKD8F.js";import"./router-B9Gh0kMO.js";function h({client:o,t:s,locale:e,toast:r}){const a=n(o),i=e==="zh-CN"?{eyebrow:"设置",title:"账号",description:"你的账号、额度和邀请码。"}:{eyebrow:"Settings",title:"Account",description:"Your account, its quota and your invite code."};return t.jsxs("div",{className:"space-y-8",children:[t.jsx(c,{eyebrow:i.eyebrow,title:i.title,description:i.description}),t.jsx(p,{client:o,t:s,locale:e,toast:r}),t.jsx(u,{client:o,locale:e,toast:r}),a?.available&&t.jsx("div",{className:"px-0.5 text-[11.5px] leading-relaxed text-fg-5",children:e==="zh-CN"?"「额度兜底」的路由与触发策略已移至「流量」标签页管理。":"Quota-fallback routing is now configured on the Traffic tab."})]})}export{h as AccountPage};
