import{s as r,b as e,a,S as i}from"./chunk-EX3LRPZG-TJXaNTSI.js";import{_ as o}from"./mermaid.core-FAsvc-qs.js";import"./chunk-XXDRQBXY-CZyPlTXo.js";import"./chunk-VR4S4FIN-DtABaMf8.js";import"./chunk-32BRIVSS-BjdMbPva.js";import"./index-D5cbSL06.js";import"./react-vendor-BMp1-Y7_.js";import"./highlight-Cfs1Rmle.js";import"./katex-C-yOSGt_.js";import"./markdown-DlgIKD8F.js";import"./router-B9Gh0kMO.js";var w={parser:a,get db(){return new i(2)},renderer:e,styles:r,init:o(t=>{t.state||(t.state={}),t.state.arrowMarkerAbsolute=t.arrowMarkerAbsolute},"init")};export{w as diagram};
